django-minimal-abstract-user
============================

Typically, Django pluggable ``User`` models suffer from the following:

* If you derive from ``django.contrib.auth.models.base_user.AbstractBaseUser``, you do not get Django Admin integration, permissions and ``manage.py createsuperuser`` (a real deal breaker for simpler projects!)
* If you derive from ``django.contrib.auth.models.AbstractUser``, you get hard-coded ``username``, ``first_name``, ``last_name`` and ``email`` (what if you don't need to separate first and last name, and don't need usernames at all?)

This library provides a better ``AbstractUser`` class which works around both problems and provides a minimal abstract base ``User`` model that doesn't have any extra fields but supports permissions and Django Admin.


Installation
============

::

        pip install django_minimal_abstract_user


Usage
=====

In ``yourproject/accounts/models.py``:

.. code:: python

	from django_minimal_abstract_user import AbstractUser
